@@ -28,6 +28,7 @@ class PrinterinfoPlugin(octoprint.plugin.EventHandlerPlugin):
         if profile:
             # send the printer name to the external API endpoint
             printer_name = profile.get("name")
+            self._logger.info(printer_name + "aquired")
             self._send_printer_name(printer_name)
 
     def _handle_print_started(self, payload):
@@ -35,6 +36,7 @@ class PrinterinfoPlugin(octoprint.plugin.EventHandlerPlugin):
         job_data = self._printer.get_current_job()
         if job_data:
             # send the print job data to the external API endpoint
+            self._logger.info(job_data + "aquired")
             self._send_print_job_data(job_data)
 
     def _send_printer_name(self, printer_name):
@@ -42,6 +44,8 @@ class PrinterinfoPlugin(octoprint.plugin.EventHandlerPlugin):
         url = "https://middleman.gavinhailey.dev/api/v1/printers"
         data = {"printer": {"name": printer_name}}
         response = requests.post(url, json=data)
+        self._logger.info(json = data)
+        self._logger.warn(response.status_code)
         if response.status_code != 200:
             self._logger.warn("Failed to send printer name to external API")
 
@@ -50,6 +54,8 @@ class PrinterinfoPlugin(octoprint.plugin.EventHandlerPlugin):
         url = "https://middleman.gavinhailey.dev/api/v1/jobs"
         data = {"job": job_data}
         response = requests.post(url, json=data)
+        self._logger.info(json = data)
+        self._logger.warn(response.status_code)
         if response.status_code != 200:
             self._logger.warn("Failed to send print job data to external API")
 
@@ -59,7 +65,7 @@ __plugin_pythoncompat__ = ">=3,<4"
 def __plugin_load__():
     global __plugin_implementation__
     __plugin_implementation__ = PrinterinfoPlugin()
-    
+
 #import octoprint.plugin
 #from octoprint.server import admin_permission
 #from octoprint.events import Events
